@@ -235,6 +235,23 @@ def LoadConfig():
 
 
 
+    try:
+        data.Light_Sleep_Level = config.getint('main', 'Light_Sleep_Level')
+    except:
+        data.Light_Sleep_Level=data.Light_Sleep_Level_default
+        config.set('main', 'Light_Sleep_Level', str(data.Light_Sleep_Level))
+
+    try:
+        data.Deep_Sleep_Level = config.getint('main', 'Deep_Sleep_Level')
+    except:
+        data.Deep_Sleep_Level=data.Deep_Sleep_Level_default
+        config.set('main', 'Deep_Sleep_Level', str(data.Deep_Sleep_Level))
+
+
+
+
+
+
 ## Add forced configuration changes here
     try:
         configFileVersion = config.getint('main', 'configFileVersion')
@@ -246,8 +263,9 @@ def LoadConfig():
             config.set('main', 'Yscale_Movement', str(data.Yscale_Movement_default))
 
             QMessageBox.critical(None, "Changes in SleepAnalyser",
-            "There are new functions and changes in SleepAnalyser. Please have a look in the help menu to see what has changed. " + \
-            "Because of the changes some parameters might need adjustment, expecially the trigger level. " + \
+            "There are many new functions and changes in SleepAnalyser. " + \
+            "Please have a look in the help menu to see what has changed. " + \
+            "Because of the changes some parameters might need adjustment. " + \
             "You can change them in the configuration dialog.")
 
     else: #config file up to date
@@ -506,4 +524,4 @@ def CloseMediaPlayer():
 #    t2=1000*(now-data.passed_time2)
 #    print "### ",  str(int(t)), "ms, (",  str(int(t2)), "ms delta): ", text
 #
-#    data.passed_time2 = time.time()
\ No newline at end of file
+#    data.passed_time2 = time.time()
